**ai2xl** is a free **Python** library that allows using **Excel** for **ML data preparation**, zero dependency **ML model deployment**, **model debugging** and **model explainability**. **Data Scientists** can use ai2xl to make their own lives easier, and also to **collaborate** with **Data Analysts**, **Business Analysts** and more. There are an estimated **1 billion+** Excel, Google Sheets, LibreOffice or similar Spreadsheet users in the World. ai2xl aims to bridge the gap between Data Scientist / Python world and the billion+ Business / Excel users.  

You can read more about ai2xl here: <a href="https://ai2xl.github.io/" target="_blank">https://ai2xl.github.io</a>

For getting started and other information: <a href="https://ai2xl.readthedocs.io/" target="_blank">https://ai2xl.readthedocs.io</a>

Sample Jupyter notebooks: <a href="https://ai2xl.github.io/samples/" target="_blank">https://ai2xl.github.io/samples</a>

Enjoy!
